@@ -65,8 +65,8 @@ EarthModel <- function(
       param = c("nprune", "degree"),
       values = c(
         function(n, data, ...) {
-          modelfit <- fit(data, model = EarthModel(pmethod = "none"))
-          max_terms <- min(2 + 0.75 * nrow(modelfit$dirs), 200)
+          model_fit <- fit(data, model = EarthModel(pmethod = "none"))
+          max_terms <- min(2 + 0.75 * nrow(model_fit$dirs), 200)
           round(seq(2, max_terms, length = n))
         },
         function(n, ...) head(1:2, n)
