@@ -36,11 +36,12 @@ PLSModel <- function(ncomp = 1, scale = FALSE) {
     response_types = c("factor", "numeric"),
     predictor_encoding = "model.matrix",
     params = params(environment()),
-    grid = function(x, length, ...) {
-      list(
-        ncomp = 1:min(nrow(x), nvars(x, PLSModel) - 1, length)
+    gridinfo = new_gridinfo(
+      param = "ncomp",
+      values = c(
+        function(n, data, ...) 1:min(nrow(data), nvars(data, PLSModel) - 1, n)
       )
-    },
+    ),
     fit = function(formula, data, weights, ...) {
       assert_equal_weights(weights)
       y <- response(data)
