@@ -48,12 +48,13 @@ QDAModel <- function(
     params = params(environment()),
     fit = function(formula, data, weights, use, ...) {
       assert_equal_weights(weights)
-      modelfit <- eval_fit(data,
-                           formula = MASS::qda(formula,
-                                               data = as.data.frame(data), ...),
-                           matrix = MASS::qda(x, y, ...))
-      modelfit$use <- use
-      modelfit
+      model_fit <- eval_fit(
+        data,
+        formula = MASS::qda(formula, data = as.data.frame(data), ...),
+        matrix = MASS::qda(x, y, ...)
+      )
+      model_fit$use <- use
+      model_fit
     },
     predict = function(object, newdata, prior = object$prior, ...) {
       newdata <- as.data.frame(newdata)
