@@ -6,6 +6,11 @@ append <- function(...) {
 setGeneric(".append", function(x, y, ...) standardGeneric(".append"))
 
 
+setMethod(".append", c("ANY", "ANY"),
+  function(x, y) c(x, y)
+)
+
+
 setMethod(".append", c("ANY", "missing"),
   function(x, y) x
 )
@@ -14,7 +19,7 @@ setMethod(".append", c("ANY", "missing"),
 setMethod(".append", c("data.frame", "data.frame"),
   function(x, y) {
     stopifnot(names(x) == names(y))
-    df <- data.frame(matrix(nrow = nrow(x) + nrow(y), ncol = 0))
+    df <- data.frame(row.names = seq_len(nrow(x) + nrow(y)))
     for (varname in names(x)) {
       df[[varname]] <- .append(x[[varname]], y[[varname]])
     }
@@ -35,27 +40,24 @@ setMethod(".append", c("matrix", "matrix"),
 
 setMethod(".append", c("ordered", "ordered"),
   function(x, y) {
-    xy <- unlist(list(x, y))
-    if (all(levels(x) == levels(y))) as.ordered(xy) else xy
+    z <- unlist(list(x, y))
+    if (identical(levels(x), levels(y))) as.ordered(z) else z
   }
 )
 
 
-setMethod(".append", c("Surv", "Surv"),
-  function(x, y) c(x, y)
-)
-
-
 setMethod(".append", c("SurvMatrix", "SurvMatrix"),
-  function(x, y) {
-    stopifnot(identical(time(x), time(y)))
-    object_class <- class(x)
-    if (!identical(object_class, class(y))) object_class <-  "SurvMatrix"
-    structure(rbind(x, y), class = object_class, times = time(x))
-  }
-)
-
-
-setMethod(".append", c("vector", "vector"),
   function(x, y) c(x, y)
 )
+
+
+setMethod(".append", c("tbl_df", "tbl_df"),
+  function(x, y) {
+    stopifnot(names(x) == names(y))
+    tbl <- tibble(.rows = nrow(x) + nrow(y))
+    for (varname in names(x)) {
+      tbl[[varname]] <- .append(x[[varname]], y[[varname]])
+    }
+    tbl
+  }
+)
