@@ -57,9 +57,9 @@ EmpiricalSurv.default <- function(x, ...) {
 }
 
 
-EmpiricalSurv.Surv <- function(y, risk = NULL, method =
-                                 c("breslow", "efron", "fleming-harrington"),
-                               ...) {
+EmpiricalSurv.Surv <- function(
+  y, risk = NULL, method = c("breslow", "efron", "fleming-harrington"), ...
+) {
   times <- y[, "time"]
   events <- pmin(y[, "status"], 1)
   if (is.null(risk)) risk <- rep(1, length(times))
@@ -264,8 +264,9 @@ surv_cases <- function(..., subset = TRUE) {
 }
 
 
-surv_dist <- function(x = c("empirical", "exponential", "rayleigh",
-                            "weibull")) {
+surv_dist <- function(
+  x = c("empirical", "exponential", "rayleigh", "weibull")
+) {
   switch(match.arg(x),
     "empirical" = EmpiricalSurv,
     "exponential" = Exponential,
