@@ -12,12 +12,19 @@ knitr::opts_chunk$set(
 library(kableExtra)
 
 
-rdoc_url <- function(name) {
+rdoc_url <- function(names, rdoc_names = NULL) {
   version <- packageVersion("MachineShop")
   url <- paste0("https://www.rdocumentation.org/packages/MachineShop/versions",
               "/", version$major, ".", version$minor, ".0",
               "/topics/")
-  paste0("[`", name, "`](", url, name, ")")
+
+  if (is.null(rdoc_names)) {
+    paren_pos <- regexpr("\\(([^)]*)\\)", names)
+    end_pos <- ifelse(paren_pos > 0, paren_pos - 1, nchar(names))
+    rdoc_names <- trimws(substr(names, 1, end_pos))
+  }
+
+  paste0("[`", names, "`](", url, rdoc_names, ")")
 }
 
 
